@@ -1,10 +1,10 @@
 fit <- function(mim,submitData=TRUE){
   if (!is.null(.latent.in.model(mim)))
     stop("Model has latent variable and 'fit' can not be used - try using 'emfit'")
-
+  
   if (submitData==FALSE){
-    #cat("WARNING: Data are not entered to MIM engine. This is not a problem\n")
-    #cat(" if the relevant data are already loaded in MIM, but no checking is performed...\n")
+    ##cat("WARNING: Data are not entered to MIM engine. This is not a problem\n")
+    ##cat(" if the relevant data are already loaded in MIM, but no checking is performed...\n")
   }
   else
     toMIM(mim$data)
@@ -16,38 +16,66 @@ fit <- function(mim,submitData=TRUE){
   return(mim)
 }
 
-emfit <- function(mim,arg="R", submitData=TRUE, emconv=0.0001, emmax=1000,plot=FALSE){
+emfit <- function(mim,arg="R", submitData=TRUE, emconv=0.0001, emmax=1000,plot=FALSE,info=FALSE){
+  time.start <- proc.time()
   if (submitData==FALSE){
-    #cat("WARNING: Data are not entered to MIM engine. This is not a problem\n")
-    #cat(" if the relevant data are already loaded in MIM, but no checking is performed...\n")
+    ##cat("WARNING: Data are not entered to MIM engine. This is not a problem\n")
+    ##cat(" if the relevant data are already loaded in MIM, but no checking is performed...\n")
   }
   else
     toMIM(mim$data)
-  if (toupper(arg)=="S")
-    .initLatent(latent(mim$data), mim$data)
-  .formula.toMIM(mim)
-  cat("Fitting using EM algorithm... ")
-  str <- paste("EMconv", sprintf("%.12f", emconv), "; EMmax", emmax)
-  mim.cmd(str, look.nice=FALSE)
-  res <- .mim.cmd.term(paste("Emfit", arg),look.nice=FALSE)
+  ##if (toupper(arg)=="S")
 
-  result<-
+  if (info==TRUE)
+    cat("Fitting using EM algorithm... ")
+  
+  .initLatent(latent(mim$data), mim$data, info)
+  .formula.toMIM(mim)
+
+  str <- paste("EMconv", sprintf("%.12f", emconv), "; EMmax", emmax)
+  if (info==TRUE)
+    cat(str,"\n")
+  
+  mim.cmd(str, look.nice=FALSE)
+  
+  res <- .mim.cmd.term(paste("Emfit", arg),look.nice=FALSE)
+  rrr <- grep(c("initialisation."), res)
+  if (toupper(arg)=="S" && length(rrr)>0){
+    cat ("Initialization with given starting values failed - trying with random starting values\n")
+    res <- .mim.cmd.term(paste("Emfit", "r"),look.nice=FALSE)
+  }
+    
+  rrr <- grep(c("Successful","Error","exceeded."), res)
+  theend<-match(c("Successful","Maximum"), res)
+  endidx <- theend[which(!is.na(theend))]
+  
+  result <-
     rbind(
           c(as.numeric(res[9:10]), NA),
-          matrix(as.numeric(res[11:(which(res=="Successful")-1)]),ncol=3,byrow=TRUE)
-          )
+          matrix(as.numeric(res[11:(endidx-1)]),ncol=3,byrow=TRUE)
+          )  
+  
   result<-as.data.frame(result)
   names(result)<-c("cycle","m2logL","change")
   if (plot != FALSE){
+    opar <- par("mfrow")
     par(mfrow=c(1,2))
-    plot(result$cycle,result$m2logL,xlab="Iteration",ylab="-2logL"); title("-2 log Likelihood");
+    plot(result$cycle,result$m2logL,xlab="Iteration",ylab="-2logL");
+    title("-2 log Likelihood");
     lines(result$cycle,result$m2logL)
-    plot(result$cycle,result$change,xlab="Iteration",ylab="Change"); title("Change in log Likelihood")
+    plot(result$cycle,result$change,xlab="Iteration",ylab="Change");
+    title("Change in log Likelihood")
     lines(result$cycle,result$change)
+    par(mfrow=opar)
   }
-  cat(nrow(result),"iterations\n")
   mim <- .retrieve.fittedMIM(mim)
-  mim$EMconvergence <- result
+
+  if (info==TRUE){
+    if(res[endidx]=="Maximum")
+      cat("Note: maximum number of iterations exceeded\n")
+    cat("Iterations", nrow(result), "Time",   (proc.time()-time.start)[3], "\n")
+  }
+  mim$EMconvergence <- result 
   return(mim)
 }
 
@@ -82,9 +110,10 @@ emfit <- function(mim,arg="R", submitData=TRUE, emconv=0.0001, emmax=1000,plot=F
     .mim.output.to.list(v)
 }
 
-.initLatent <- function(set, data){
+.initLatent <- function(set, data, info=FALSE){
     s <- .look.up.mim.names(set, data, "to.mim")
-    cat("Initializing latent variables:", paste(set, collapse=' '), "\n")
+    if (info==TRUE)
+      cat("Initializing latent variables:", paste(set, collapse=' '), "\n")
     s2<- paste("calc", s, "=", s, "+ln(0);")
     mim.cmd(s2)
 }
