@@ -125,3 +125,9 @@ mcm <- function(){
   return( invisible(value) );
 }
 
+.mim.cmd.file <- function(mim.cmds){
+  file     <- paste(getwd(),"\\","mimCMD.txt",sep='')
+  write("%\n% COMMAND FILE GENERATED BY mimR", file, append=FALSE)
+  lapply(mim.cmds, write, file,append=TRUE)
+  mim.cmd(paste("input",file))
+} 
